@@ -50,12 +50,12 @@ void Sharing::postToFacebook(const QString &site, const QString &videoId, const
     QByteArray postData;
 
     postData = "access_token=" + facebookToken.toAscii()
-            + "&message=" + message.toAscii()
+            + "&message=" + message.toAscii().toPercentEncoding()
             + "&link=" + playerUrl
             + "&source=" + embedUrl
             + "&picture=" + thumbUrl
-            + "&name=" + title.toAscii()
-            + "&description=" + description.toAscii();
+            + "&name=" + title.toAscii().toPercentEncoding()
+            + "&description=" + description.toAscii().toPercentEncoding();
 
 //    qDebug() << postData;
 
